/*
 * Copyright © 2015 Red Hat, Inc
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *       Alexander Larsson <alexl@redhat.com>
 */

#ifndef __FLATPAK_H__
#define __FLATPAK_H__

#define __FLATPAK_H_INSIDE__

#include <gio/gio.h>

#include <flatpak-version-macros.h>
#include <flatpak-enum-types.h>
#include <flatpak-error.h>
#include <flatpak-portal-error.h>
#include <flatpak-ref.h>
#include <flatpak-installed-ref.h>
#include <flatpak-remote-ref.h>
#include <flatpak-related-ref.h>
#include <flatpak-bundle-ref.h>
#include <flatpak-remote.h>
#include <flatpak-installation.h>
#include <flatpak-transaction.h>
#include <flatpak-instance.h>

#undef __FLATPAK_H_INSIDE__

#endif /* __FLATPAK_H__ */
